==> open-cluster-management-discovery-model-6.5.1-sources.jar: io/fabric8/openclustermanagement/api/model/discovery/v1alpha1/DiscoveryConfigFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.discovery.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DiscoveryConfigFluentImpl<A extends DiscoveryConfigFluent<A>> extends BaseFluent<A> implements DiscoveryConfigFluent<A>{
  public DiscoveryConfigFluentImpl() {
  }
  public DiscoveryConfigFluentImpl(DiscoveryConfig instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private DiscoveryConfigSpecBuilder spec;
  private DiscoveryConfigStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public DiscoveryConfigFluent.MetadataNested<A> withNewMetadata() {
    return new DiscoveryConfigFluentImpl.MetadataNestedImpl();
  }
  public DiscoveryConfigFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new DiscoveryConfigFluentImpl.MetadataNestedImpl(item);
  }
  public DiscoveryConfigFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public DiscoveryConfigFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public DiscoveryConfigFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public DiscoveryConfigSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public DiscoveryConfigSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(DiscoveryConfigSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new DiscoveryConfigSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public DiscoveryConfigFluent.SpecNested<A> withNewSpec() {
    return new DiscoveryConfigFluentImpl.SpecNestedImpl();
  }
  public DiscoveryConfigFluent.SpecNested<A> withNewSpecLike(DiscoveryConfigSpec item) {
    return new DiscoveryConfigFluentImpl.SpecNestedImpl(item);
  }
  public DiscoveryConfigFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public DiscoveryConfigFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new DiscoveryConfigSpecBuilder().build());
  }
  public DiscoveryConfigFluent.SpecNested<A> editOrNewSpecLike(DiscoveryConfigSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public DiscoveryConfigStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public DiscoveryConfigStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(DiscoveryConfigStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new DiscoveryConfigStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public DiscoveryConfigFluent.StatusNested<A> withNewStatus() {
    return new DiscoveryConfigFluentImpl.StatusNestedImpl();
  }
  public DiscoveryConfigFluent.StatusNested<A> withNewStatusLike(DiscoveryConfigStatus item) {
    return new DiscoveryConfigFluentImpl.StatusNestedImpl(item);
  }
  public DiscoveryConfigFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public DiscoveryConfigFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new DiscoveryConfigStatusBuilder().build());
  }
  public DiscoveryConfigFluent.StatusNested<A> editOrNewStatusLike(DiscoveryConfigStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DiscoveryConfigFluentImpl that = (DiscoveryConfigFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<DiscoveryConfigFluent.MetadataNested<N>> implements DiscoveryConfigFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) DiscoveryConfigFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends DiscoveryConfigSpecFluentImpl<DiscoveryConfigFluent.SpecNested<N>> implements DiscoveryConfigFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(DiscoveryConfigSpec item) {
      this.builder = new DiscoveryConfigSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new DiscoveryConfigSpecBuilder(this);
    }
    DiscoveryConfigSpecBuilder builder;
    public N and() {
      return (N) DiscoveryConfigFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends DiscoveryConfigStatusFluentImpl<DiscoveryConfigFluent.StatusNested<N>> implements DiscoveryConfigFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(DiscoveryConfigStatus item) {
      this.builder = new DiscoveryConfigStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new DiscoveryConfigStatusBuilder(this);
    }
    DiscoveryConfigStatusBuilder builder;
    public N and() {
      return (N) DiscoveryConfigFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-discovery-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/discovery/v1alpha1/DiscoveryConfigFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.discovery.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DiscoveryConfigFluentImpl<A extends DiscoveryConfigFluent<A>> extends BaseFluent<A> implements DiscoveryConfigFluent<A>{
  public DiscoveryConfigFluentImpl() {
  }
  public DiscoveryConfigFluentImpl(DiscoveryConfig instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private DiscoveryConfigSpecBuilder spec;
  private DiscoveryConfigStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public DiscoveryConfigFluentImpl.MetadataNested<A> withNewMetadata() {
    return new DiscoveryConfigFluentImpl.MetadataNestedImpl();
  }
  public DiscoveryConfigFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new DiscoveryConfigFluentImpl.MetadataNestedImpl(item);
  }
  public DiscoveryConfigFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public DiscoveryConfigFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public DiscoveryConfigFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public DiscoveryConfigSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public DiscoveryConfigSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(DiscoveryConfigSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new DiscoveryConfigSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public DiscoveryConfigFluentImpl.SpecNested<A> withNewSpec() {
    return new DiscoveryConfigFluentImpl.SpecNestedImpl();
  }
  public DiscoveryConfigFluentImpl.SpecNested<A> withNewSpecLike(DiscoveryConfigSpec item) {
    return new DiscoveryConfigFluentImpl.SpecNestedImpl(item);
  }
  public DiscoveryConfigFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public DiscoveryConfigFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new DiscoveryConfigSpecBuilder().build());
  }
  public DiscoveryConfigFluentImpl.SpecNested<A> editOrNewSpecLike(DiscoveryConfigSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public DiscoveryConfigStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public DiscoveryConfigStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(DiscoveryConfigStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new DiscoveryConfigStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public DiscoveryConfigFluentImpl.StatusNested<A> withNewStatus() {
    return new DiscoveryConfigFluentImpl.StatusNestedImpl();
  }
  public DiscoveryConfigFluentImpl.StatusNested<A> withNewStatusLike(DiscoveryConfigStatus item) {
    return new DiscoveryConfigFluentImpl.StatusNestedImpl(item);
  }
  public DiscoveryConfigFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public DiscoveryConfigFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new DiscoveryConfigStatusBuilder().build());
  }
  public DiscoveryConfigFluentImpl.StatusNested<A> editOrNewStatusLike(DiscoveryConfigStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DiscoveryConfigFluentImpl that = (DiscoveryConfigFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<DiscoveryConfigFluentImpl.MetadataNested<N>> implements DiscoveryConfigFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) DiscoveryConfigFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends DiscoveryConfigSpecFluentImpl<DiscoveryConfigFluentImpl.SpecNested<N>> implements DiscoveryConfigFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(DiscoveryConfigSpec item) {
      this.builder = new DiscoveryConfigSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new DiscoveryConfigSpecBuilder(this);
    }
    DiscoveryConfigSpecBuilder builder;
    public N and() {
      return (N) DiscoveryConfigFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends DiscoveryConfigStatusFluentImpl<DiscoveryConfigFluentImpl.StatusNested<N>> implements DiscoveryConfigFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(DiscoveryConfigStatus item) {
      this.builder = new DiscoveryConfigStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new DiscoveryConfigStatusBuilder(this);
    }
    DiscoveryConfigStatusBuilder builder;
    public N and() {
      return (N) DiscoveryConfigFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
